logger

package
v0.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2023 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CleanupLogger

func CleanupLogger()

CleanupLogger cleans up the logger system before the app exits

func EmergencyLogToFile added in v0.3.3

func EmergencyLogToFile(filename string, message string)

EmergencyLogToFile logs the specified message to the specified file. To be used when the logger facility is not available.

func GetFuncLogger

func GetFuncLogger(existingLog zerolog.Logger, funcName string) zerolog.Logger

GetFuncLogger returns a new logger based on the supplied logger with a string field `func` set to the supplied funcName

func GetLogger

func GetLogger(funcName string) zerolog.Logger

GetLogger returns a new logger with a string field `func` set to the supplied funcName

func GetPackageLogger

func GetPackageLogger(packageName string) zerolog.Logger

GetPackageLogger returns a new logger with a string field `package` set to the supplied packageName

func GetStructLogger

func GetStructLogger(structName string) zerolog.Logger

GetStructLogger returns a new logger with a string field `struct` set to the supplied structname

func InitLogger

func InitLogger(logLevel string, console bool)

InitLogger initializes the logger system

Types

This section is empty.

Jump to