Documentation
¶
Index ¶
- func CleanupLogger()
- func EmergencyLogToFile(filename string, message string)
- func GetFuncLogger(existingLog zerolog.Logger, funcName string) zerolog.Logger
- func GetLogger(funcName string) zerolog.Logger
- func GetPackageLogger(packageName string) zerolog.Logger
- func GetStructLogger(structName string) zerolog.Logger
- func InitLogger(logLevel string, console bool)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CleanupLogger ¶
func CleanupLogger()
CleanupLogger cleans up the logger system before the app exits
func EmergencyLogToFile ¶ added in v0.3.3
EmergencyLogToFile logs the specified message to the specified file. To be used when the logger facility is not available.
func GetFuncLogger ¶
GetFuncLogger returns a new logger based on the supplied logger with a string field `func` set to the supplied funcName
func GetLogger ¶
GetLogger returns a new logger with a string field `func` set to the supplied funcName
func GetPackageLogger ¶
GetPackageLogger returns a new logger with a string field `package` set to the supplied packageName
func GetStructLogger ¶
GetStructLogger returns a new logger with a string field `struct` set to the supplied structname
func InitLogger ¶
InitLogger initializes the logger system
Types ¶
This section is empty.